Class: KnapsackPro::SlowTestFileDeterminer

Inherits:
Object
  • Object
show all
Defined in:
lib/knapsack_pro/slow_test_file_determiner.rb

Constant Summary collapse

TIME_THRESHOLD_PER_CI_NODE =

70%

0.7

Class Method Summary collapse

Class Method Details

.call(test_files) ⇒ Object

test_files: { ‘path’ => ‘a_spec.rb’, ‘time_execution’ => 0.0 }



8
9
10
11
12
13
14
15
16
17
18
19
20
# File 'lib/knapsack_pro/slow_test_file_determiner.rb', line 8

def self.call(test_files)
  total_execution_time = test_files.sum { |test_file| test_file.fetch('time_execution') }
  time_threshold = (total_execution_time / KnapsackPro::Config::Env.ci_node_total) * TIME_THRESHOLD_PER_CI_NODE

  test_files.select do |test_file|
    execution_time = test_file.fetch('time_execution')
    next false if execution_time.zero?
    next true if execution_time >= time_threshold
    next false unless KnapsackPro::Config::Env.slow_test_file_threshold?

    execution_time >= KnapsackPro::Config::Env.slow_test_file_threshold
  end
end

.read_from_json_reportObject



28
29
30
31
32
# File 'lib/knapsack_pro/slow_test_file_determiner.rb', line 28

def self.read_from_json_report
  raise "The report with slow test files has not been generated yet. If you have enabled split by test cases #{KnapsackPro::Urls::SPLIT_BY_TEST_EXAMPLES} and you see this error it means that your tests accidentally cleaned up the .knapsack_pro directory. Please do not remove this directory during tests runtime!" unless File.exist?(report_path)
  slow_test_files_json_report = File.read(report_path)
  JSON.parse(slow_test_files_json_report)
end

.save_to_json_report(test_files) ⇒ Object



22
23
24
25
26
# File 'lib/knapsack_pro/slow_test_file_determiner.rb', line 22

def self.save_to_json_report(test_files)
  KnapsackPro::Config::TempFiles.ensure_temp_directory_exists!
  FileUtils.mkdir_p(report_dir)
  File.write(report_path, test_files.to_json)
end