Class: KnapsackPro::Adapters::BaseAdapter
- Inherits:
-
Object
- Object
- KnapsackPro::Adapters::BaseAdapter
show all
- Defined in:
- lib/knapsack_pro/adapters/base_adapter.rb
Constant Summary
collapse
- TEST_DIR_PATTERN =
Just example, please overwrite constant in subclass
'test/**{,/*/**}/*_test.rb'
Class Method Summary
collapse
Instance Method Summary
collapse
Class Method Details
.adapter_bind_method_called_file ⇒ Object
.bind ⇒ Object
22
23
24
25
26
|
# File 'lib/knapsack_pro/adapters/base_adapter.rb', line 22
def self.bind
adapter = new
adapter.bind
adapter
end
|
.calculate_slow_id_paths ⇒ Object
18
19
20
|
# File 'lib/knapsack_pro/adapters/base_adapter.rb', line 18
def self.calculate_slow_id_paths
raise NotImplementedError
end
|
.split_by_test_cases_enabled? ⇒ Boolean
14
15
16
|
# File 'lib/knapsack_pro/adapters/base_adapter.rb', line 14
def self.split_by_test_cases_enabled?
false
end
|
.verify_bind_method_called ⇒ Object
28
29
30
31
32
33
34
35
36
37
38
|
# File 'lib/knapsack_pro/adapters/base_adapter.rb', line 28
def self.verify_bind_method_called
::Kernel.at_exit do
if File.exist?(adapter_bind_method_called_file)
File.delete(adapter_bind_method_called_file)
else
KnapsackPro.logger.error("The `#{self}.bind` method was not called in the test runner configuration. See: #{KnapsackPro::Urls::INSTALLATION_GUIDE}")
KnapsackPro.logger.error("If `#{self}.bind` was called and you still see this error, ensure the `.knapsack_pro` directory (or its contents) were not removed during the run: #{KnapsackPro::Urls::DASHBOARD__ZEROISH_TEST_EXECUTION_TIMES}")
Kernel.exit(1)
end
end
end
|
Instance Method Details
#bind_after_queue_hook ⇒ Object
68
69
70
|
# File 'lib/knapsack_pro/adapters/base_adapter.rb', line 68
def bind_after_queue_hook
raise NotImplementedError
end
|
#bind_before_queue_hook ⇒ Object
64
65
66
|
# File 'lib/knapsack_pro/adapters/base_adapter.rb', line 64
def bind_before_queue_hook
raise NotImplementedError
end
|
#bind_queue_mode ⇒ Object
72
73
74
75
76
|
# File 'lib/knapsack_pro/adapters/base_adapter.rb', line 72
def bind_queue_mode
bind_before_queue_hook
bind_after_queue_hook
bind_time_tracker
end
|
#bind_save_report ⇒ Object
60
61
62
|
# File 'lib/knapsack_pro/adapters/base_adapter.rb', line 60
def bind_save_report
raise NotImplementedError
end
|
#bind_time_tracker ⇒ Object
56
57
58
|
# File 'lib/knapsack_pro/adapters/base_adapter.rb', line 56
def bind_time_tracker
raise NotImplementedError
end
|