Class: KnapsackPro::Adapters::RSpecAdapter
Constant Summary
collapse
- TEST_DIR_PATTERN =
'spec/**{,/*/**}/*_spec.rb'
Class Method Summary
collapse
Instance Method Summary
collapse
Methods inherited from BaseAdapter
adapter_bind_method_called_file, bind, #bind, #bind_queue_mode, slow_test_file?, verify_bind_method_called
Class Method Details
.ensure_no_tag_option_when_rspec_split_by_test_examples_enabled!(cli_args) ⇒ Object
.file_path_for(example) ⇒ Object
59
60
61
62
63
64
65
66
67
68
69
70
71
72
|
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 59
def self.file_path_for(example)
[
-> { parse_file_path(example.id) },
-> { example.metadata[:file_path] },
-> { example.metadata[:example_group][:file_path] },
-> { top_level_group(example)[:file_path] },
]
.each do |path|
p = path.call
return p if p.include?('_spec.rb') || p.include?('.feature')
end
return ''
end
|
51
52
53
|
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 51
def self.has_format_option?(cli_args)
!!parsed_options(cli_args)&.[](:formatters)
end
|
.has_tag_option?(cli_args) ⇒ Boolean
47
48
49
|
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 47
def self.has_tag_option?(cli_args)
!!parsed_options(cli_args)&.[](:inclusion_filter)
end
|
.order_option(cli_args) ⇒ Object
55
56
57
|
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 55
def self.order_option(cli_args)
parsed_options(cli_args)&.[](:order)
end
|
.parse_file_path(id) ⇒ Object
74
75
76
77
|
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 74
def self.parse_file_path(id)
id.match(/\A(.*?)(?:\[([\d\s:,]+)\])?\z/).captures.first
end
|
.split_by_test_cases_enabled? ⇒ Boolean
10
11
12
13
14
15
16
17
18
19
|
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 10
def self.split_by_test_cases_enabled?
return false unless KnapsackPro::Config::Env.rspec_split_by_test_examples?
require 'rspec/core/version'
unless Gem::Version.new(::RSpec::Core::Version::STRING) >= Gem::Version.new('3.3.0')
raise "RSpec >= 3.3.0 is required to split test files by test examples. Learn more: #{KnapsackPro::Urls::SPLIT_BY_TEST_EXAMPLES}"
end
true
end
|
.test_file_cases_for(slow_test_files) ⇒ Object
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
|
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 21
def self.test_file_cases_for(slow_test_files)
KnapsackPro.logger.info("Generating RSpec test examples JSON report for slow test files to prepare it to be split by test examples (by individual test cases). Thanks to that, a single slow test file can be split across parallel CI nodes. Analyzing #{slow_test_files.size} slow test files.")
cmd = [
'RACK_ENV=test',
'RAILS_ENV=test',
KnapsackPro::Config::Env.rspec_test_example_detector_prefix,
'rake knapsack_pro:rspec_test_example_detector',
].join(' ')
unless Kernel.system(cmd)
raise "Could not generate JSON report for RSpec. Rake task failed when running #{cmd}"
end
KnapsackPro::TestCaseDetectors::RSpecTestExampleDetector.new.test_file_example_paths
end
|
.top_level_group(example) ⇒ Object
80
81
82
83
84
85
86
|
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 80
def self.top_level_group(example)
group = example.metadata[:example_group]
until group[:parent_example_group].nil?
group = group[:parent_example_group]
end
group
end
|
Instance Method Details
#bind_after_queue_hook ⇒ Object
137
138
139
140
141
142
143
|
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 137
def bind_after_queue_hook
::RSpec.configure do |config|
config.after(:suite) do
KnapsackPro::Hooks::Queue.call_after_queue
end
end
end
|
#bind_before_queue_hook ⇒ Object
129
130
131
132
133
134
135
|
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 129
def bind_before_queue_hook
::RSpec.configure do |config|
config.before(:suite) do
KnapsackPro::Hooks::Queue.call_before_queue
end
end
end
|
#bind_save_report ⇒ Object
#bind_time_tracker ⇒ Object
88
89
90
91
|
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 88
def bind_time_tracker
ensure_no_focus!
log_tests_duration
end
|
#ensure_no_focus! ⇒ Object
#log_tests_duration ⇒ Object