Class: KnapsackPro::Adapters::RSpecAdapter

Inherits:
BaseAdapter
  • Object
show all
Defined in:
lib/knapsack_pro/adapters/rspec_adapter.rb

Direct Known Subclasses

RspecAdapter

Constant Summary collapse

TEST_DIR_PATTERN =
'spec/**{,/*/**}/*_spec.rb'

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseAdapter

adapter_bind_method_called_file, bind, #bind, #bind_queue_mode, slow_test_file?, verify_bind_method_called

Class Method Details

.ensure_no_tag_option_when_rspec_split_by_test_examples_enabled!(cli_args) ⇒ Object



8
9
10
11
12
13
14
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 8

def self.ensure_no_tag_option_when_rspec_split_by_test_examples_enabled!(cli_args)
  if KnapsackPro::Config::Env.rspec_split_by_test_examples? && has_tag_option?(cli_args)
    error_message = "It is not allowed to use the RSpec tag option together with the RSpec split by test examples feature. Please see: #{KnapsackPro::Urls::RSPEC__SPLIT_BY_TEST_EXAMPLES__TAG}"
    KnapsackPro.logger.error(error_message)
    raise error_message
  end
end

.has_format_option?(cli_args) ⇒ Boolean

Returns:

  • (Boolean)


20
21
22
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 20

def self.has_format_option?(cli_args)
  !!parsed_options(cli_args)&.[](:formatters)
end

.has_tag_option?(cli_args) ⇒ Boolean

Returns:

  • (Boolean)


16
17
18
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 16

def self.has_tag_option?(cli_args)
  !!parsed_options(cli_args)&.[](:inclusion_filter)
end

.order_option(cli_args) ⇒ Object



24
25
26
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 24

def self.order_option(cli_args)
  parsed_options(cli_args)&.[](:order)
end

.test_path(example) ⇒ Object



28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 28

def self.test_path(example)
  example_group = example.[:example_group]

  if defined?(::Turnip) && Gem::Version.new(::Turnip::VERSION) < Gem::Version.new('2.0.0')
    unless example_group[:turnip]
      until example_group[:parent_example_group].nil?
        example_group = example_group[:parent_example_group]
      end
    end
  else
    until example_group[:parent_example_group].nil?
      example_group = example_group[:parent_example_group]
    end
  end

  example_group[:file_path]
end

Instance Method Details

#bind_before_queue_hookObject



97
98
99
100
101
102
103
104
105
106
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 97

def bind_before_queue_hook
  ::RSpec.configure do |config|
    config.before(:suite) do
      unless ENV['KNAPSACK_PRO_BEFORE_QUEUE_HOOK_CALLED']
        ENV['KNAPSACK_PRO_BEFORE_QUEUE_HOOK_CALLED'] = 'true'
        KnapsackPro::Hooks::Queue.call_before_queue
      end
    end
  end
end

#bind_save_reportObject



89
90
91
92
93
94
95
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 89

def bind_save_report
  ::RSpec.configure do |config|
    config.after(:suite) do
      KnapsackPro::Report.save
    end
  end
end

#bind_time_trackerObject



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 46

def bind_time_tracker
  ::RSpec.configure do |config|
    config.prepend_before(:context) do
      KnapsackPro.tracker.start_timer
    end

    config.around(:each) do |example|
      current_test_path = KnapsackPro::Adapters::RSpecAdapter.test_path(example)

      # Stop timer to update time for a previously run test example.
      # This way we count time spent in runtime for the previous test example after around(:each) is already done.
      # Only do that if we're in the same test file. Otherwise, `before(:all)` execution time in the current file
      # will be applied to the previously ran test file.
      if KnapsackPro.tracker.current_test_path&.start_with?(KnapsackPro::TestFileCleaner.clean(current_test_path))
        KnapsackPro.tracker.stop_timer
      end

      KnapsackPro.tracker.current_test_path =
        if KnapsackPro::Config::Env.rspec_split_by_test_examples? && KnapsackPro::Adapters::RSpecAdapter.slow_test_file?(RSpecAdapter, current_test_path)
          example.id
        else
          current_test_path
        end

      if example.[:focus] && KnapsackPro::Adapters::RSpecAdapter.rspec_configuration.filter.rules[:focus]
        raise "We detected a test file path #{current_test_path} with a test using the metadata `:focus` tag. RSpec might not run some tests in the Queue Mode (causing random tests skipping problem). Please remove the `:focus` tag from your codebase. See more: #{KnapsackPro::Urls::RSPEC__SKIPS_TESTS}"
      end

      example.run
    end

    config.append_after(:context) do
      # after(:context) hook is run one time only, after all of the examples in a group
      # stop timer to count time for the very last executed test example
      KnapsackPro.tracker.stop_timer
    end

    config.after(:suite) do
      KnapsackPro.logger.debug(KnapsackPro::Presenter.global_time)
    end
  end
end