Class: KnapsackPro::Adapters::RspecAdapter
- Inherits:
-
RSpecAdapter
- Object
- BaseAdapter
- RSpecAdapter
- KnapsackPro::Adapters::RspecAdapter
- Defined in:
- lib/knapsack_pro/adapters/rspec_adapter.rb
Overview
This is added to provide backwards compatibility In case someone is doing switch from knapsack gem to the knapsack_pro gem and didn’t notice the class name changed
Constant Summary
Constants inherited from RSpecAdapter
KnapsackPro::Adapters::RSpecAdapter::TEST_DIR_PATTERN
Constants inherited from BaseAdapter
Class Method Summary collapse
Methods inherited from RSpecAdapter
#bind_before_queue_hook, #bind_save_report, #bind_time_tracker, ensure_no_tag_option_when_rspec_split_by_test_examples_enabled!, has_format_option?, has_tag_option?, order_option, split_by_test_cases_enabled?, test_file_cases_for, test_path
Methods inherited from BaseAdapter
adapter_bind_method_called_file, #bind, #bind_before_queue_hook, #bind_queue_mode, #bind_save_report, #bind_time_tracker, slow_test_file?, split_by_test_cases_enabled?, test_file_cases_for, verify_bind_method_called
Class Method Details
.bind ⇒ Object
156 157 158 159 160 |
# File 'lib/knapsack_pro/adapters/rspec_adapter.rb', line 156 def self.bind = "You have attempted to call KnapsackPro::Adapters::RspecAdapter.bind. Please switch to using the new class name: KnapsackPro::Adapters::RSpecAdapter. See #{KnapsackPro::Urls::INSTALLATION_GUIDE} for up-to-date configuration instructions." KnapsackPro.logger.error() raise end |