Class: KnapsackPro::BuildDistributionFetcher::BuildDistributionEntity
- Inherits:
-
Object
- Object
- KnapsackPro::BuildDistributionFetcher::BuildDistributionEntity
- Defined in:
- lib/knapsack_pro/build_distribution_fetcher.rb
Instance Method Summary collapse
-
#initialize(response) ⇒ BuildDistributionEntity
constructor
A new instance of BuildDistributionEntity.
- #test_files ⇒ Object
-
#test_queue_url ⇒ Object
Can be present only when using the initialize command.
Constructor Details
#initialize(response) ⇒ BuildDistributionEntity
Returns a new instance of BuildDistributionEntity.
6 7 8 |
# File 'lib/knapsack_pro/build_distribution_fetcher.rb', line 6 def initialize(response) @response = response end |
Instance Method Details
#test_files ⇒ Object
10 11 12 |
# File 'lib/knapsack_pro/build_distribution_fetcher.rb', line 10 def test_files response.fetch('test_files') end |
#test_queue_url ⇒ Object
Can be present only when using the initialize command
14 15 16 |
# File 'lib/knapsack_pro/build_distribution_fetcher.rb', line 14 def test_queue_url # Can be present only when using the initialize command response.fetch('test_queue_url', nil) end |