Module: KnapsackPro::Extensions::RSpecExtension
- Defined in:
- lib/knapsack_pro/extensions/rspec_extension.rb
Overview
Facade to abstract calls to internal RSpec methods. To allow comparing the monkey patch with the original RSpec code, keep a similar method structure and permalink to the source.
Defined Under Namespace
Modules: Configuration, Runner, World Classes: Seed
Class Method Summary collapse
Class Method Details
.setup! ⇒ Object
10 11 12 13 14 |
# File 'lib/knapsack_pro/extensions/rspec_extension.rb', line 10 def self.setup! RSpec::Core::World.prepend(World) RSpec::Core::Runner.prepend(Runner) RSpec::Core::Configuration.prepend(Configuration) end |