Class: KnapsackPro::Runners::RSpecRunner
- Inherits:
-
BaseRunner
- Object
- BaseRunner
- KnapsackPro::Runners::RSpecRunner
- Defined in:
- lib/knapsack_pro/runners/rspec_runner.rb
Class Method Summary collapse
Methods inherited from BaseRunner
#initialize, #stringify_test_file_paths, #test_dir, #test_file_paths, #test_files_to_execute_exist?
Constructor Details
This class inherits a constructor from KnapsackPro::Runners::BaseRunner
Class Method Details
.run(args) ⇒ Object
4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/knapsack_pro/runners/rspec_runner.rb', line 4 def self.run(args) require 'rspec/core' ENV['KNAPSACK_PRO_TEST_SUITE_TOKEN'] = KnapsackPro::Config::Env.test_suite_token_rspec ENV['KNAPSACK_PRO_RECORDING_ENABLED'] = 'true' adapter_class = KnapsackPro::Adapters::RSpecAdapter KnapsackPro::Config::Env.set_test_runner_adapter(adapter_class) runner = new(adapter_class) if runner.test_files_to_execute_exist? adapter_class.verify_bind_method_called cli_args = (args || '').split adapter_class.ensure_no_tag_option_when_rspec_split_by_test_examples_enabled!(cli_args) KnapsackPro.tracker.set_prerun_tests(runner.test_file_paths) require 'rspec/core/rake_task' task_name = 'knapsack_pro:rspec_run' if Rake::Task.task_defined?(task_name) Rake::Task[task_name].clear end ::RSpec::Core::RakeTask.new(task_name) do |t| # we cannot pass runner.test_file_paths array to t.pattern # because pattern does not accept test example path like spec/a_spec.rb[1:2] # instead we pass test files and test example paths to t.rspec_opts t.pattern = [] t.rspec_opts = "#{args} --default-path #{runner.test_dir} #{runner.stringify_test_file_paths}" end Rake::Task[task_name].invoke end end |